OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Non é posíbel escribir no directorio «config»!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Isto normalmente pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de configuración.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Mais, se prefire manter o ficheiro config.php como de só lectura, estabeleza a opción «config_is_read_only» como verdadeira nel.",
    "See %s" : "Vexa %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "A aplicación %1$s non está presente ou ten unha versión non compatíbel con este servidor. Comprobe o directorio de aplicacións.",
    "Sample configuration detected" : "Detectouse a configuración de exemplo",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Detectouse que foi copiada a configuración de exemplo. Isto pode rachar a súa instalación e non é compatíbel. Lea a documentación antes de facer cambios en config.php",
    "The page could not be found on the server." : "Non foi posíbel atopar a páxina no servidor.",
    "%s email verification" : "Verificación do correo-e %s",
    "Email verification" : "Verificación do correo-e",
    "Click the following button to confirm your email." : "Prema no seguinte botón para confirmar o seu correo-e.",
    "Click the following link to confirm your email." : "Prema na seguinte ligazón para confirmar o seu correo-e.",
    "Confirm your email" : "Confirmar o seu correo-e",
    "Other activities" : "Outras actividades",
    "%1$s and %2$s" : "%1$s e %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s e %5$s",
    "Education Edition" : "Edición para educación",
    "Enterprise bundle" : "Paquete empresarial",
    "Groupware bundle" : "Paquete de software colaborativo",
    "Hub bundle" : "Paquete de concentradores",
    "Social sharing bundle" : "Paquete para compartir en redes sociais",
    "PHP %s or higher is required." : "Precísase de PHP %s ou superior.",
    "PHP with a version lower than %s is required." : "Precísase de PHP cunha versión inferior a %s.",
    "%sbit or higher PHP required." : "Precísase de PHP para %s bits ou superior.",
    "The following architectures are supported: %s" : "Admítense as seguintes arquitecturas: %s",
    "The following databases are supported: %s" : "Admítense as seguintes bases de datos: %s",
    "The command line tool %s could not be found" : "Non foi posíbel atopar a ferramenta de liña de ordes %s",
    "The library %s is not available." : "Non está dispoñíbel a biblioteca %s.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Precísase da biblioteca %1$s cunha versión superior a %2$s - dispoñíbel a versión %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Precísase da biblioteca %1$s cunha versión inferior a %2$s - dispoñíbel a versión %3$s.",
    "The following platforms are supported: %s" : "Admítense as seguintes plataformas: %s",
    "Server version %s or higher is required." : "Precísase da versión %s ou superior do servidor.",
    "Server version %s or lower is required." : "Precísase da versión %s ou inferior do servidor.",
    "Wiping of device %s has started" : "Iniciouse a limpeza do dispositivo %s",
    "Wiping of device »%s« has started" : "Iniciouse a limpeza do dispositivo «%s»",
    "»%s« started remote wipe" : "«%s» iniciou a limpeza remota",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "O dispositivo ou aplicación «%s» iniciou o proceso remoto de limpeza. Recibirá outro correo  cando remate o proceso",
    "Wiping of device %s has finished" : "Rematou a limpeza do dispositivo %s",
    "Wiping of device »%s« has finished" : "Rematou a limpeza do dispositivo «%s»",
    "»%s« finished remote wipe" : "«%s» rematou a limpeza remota",
    "Device or application »%s« has finished the remote wipe process." : "O dispositivo ou aplicación «%s» rematou o proceso remoto de limpeza.",
    "Remote wipe started" : "Iniciouse a limpeza remota",
    "A remote wipe was started on device %s" : "Iniciouse unha limpeza remota no dispositivo %s",
    "Remote wipe finished" : "Rematou a limpeza remota",
    "The remote wipe on %s has finished" : "A limpeza remota en %s rematou",
    "Authentication" : "Autenticación",
    "Unknown filetype" : "Tipo de ficheiro descoñecido",
    "Invalid image" : "Imaxe incorrecta",
    "Avatar image is not square" : "A imaxe do avatar non é un cadrado",
    "Files" : "Ficheiros",
    "View profile" : "Ver o perfil",
    "Local time: %s" : "Hora local: %s",
    "today" : "hoxe",
    "tomorrow" : "mañá",
    "yesterday" : "onte",
    "_in %n day_::_in %n days_" : ["en %n día","en %n días"],
    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n días"],
    "next month" : "o vindeiro mes",
    "last month" : "o mes pasado",
    "_in %n month_::_in %n months_" : ["en %n mes","en %n meses"],
    "_%n month ago_::_%n months ago_" : ["Hai %n mes","Hai %n meses"],
    "next year" : "o vindeiro ano",
    "last year" : "o ano pasado",
    "_in %n year_::_in %n years_" : ["en %n ano","en %n anos"],
    "_%n year ago_::_%n years ago_" : ["Hai %n ano","Hai %n anos"],
    "_in %n hour_::_in %n hours_" : ["en %n hora","en %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["Hai %n hora","Hai %n horas"],
    "_in %n minute_::_in %n minutes_" : ["en %n minuto","en %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["Hai %n minuto","Hai %n minutos"],
    "in a few seconds" : "en poucos segundos",
    "seconds ago" : "segundos atrás",
    "Empty file" : "Ficheiro baleiro",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Non existe o módulo co ID: %s. Actíveo nos axustes das aplicacións ou contacte coa administración desta instancia.",
    "File already exists" : "O ficheiro xa existe",
    "Invalid path" : "Ruta incorrecta.",
    "Failed to create file from template" : "Produciuse un fallo ao crear un ficheiro a partir do modelo",
    "Templates" : "Modelos",
    "File name is a reserved word" : "O nome de ficheiro é unha palabra reservada",
    "File name contains at least one invalid character" : "O nome de ficheiro contén algún carácter incorrecto",
    "File name is too long" : "O nome de ficheiro é longo de máis",
    "Dot files are not allowed" : "Non se admiten os ficheiros con punto",
    "Empty filename is not allowed" : "Non está permitido deixar baleiro o nome de ficheiro",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Non é posíbel instalar a aplicación «%s» por mor de non poder ler o ficheiro appinfo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Non é posíbel instalar a aplicación «%s» por mor de non ser compatíbel con esta versión do servidor.",
    "__language_name__" : "Galego",
    "This is an automatically sent email, please do not reply." : "Este é un correo enviado automaticamente, non responda.",
    "Help" : "Axuda",
    "Appearance and accessibility" : "Aspecto e accesibilidade",
    "Apps" : "Aplicacións",
    "Personal settings" : "Axustes persoais",
    "Administration settings" : "Axustes de administración",
    "Settings" : "Axustes",
    "Log out" : "Saír",
    "Users" : "Usuarios",
    "Email" : "Correo-e",
    "Mail %s" : "Correo %s",
    "Fediverse" : "Fediverso",
    "View %s on the fediverse" : "Ver %s no fediverso",
    "Phone" : "Teléfono",
    "Call %s" : "Chamar %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Ver %s en Twitter",
    "Website" : "Sitio web",
    "Visit %s" : "Visitar %s",
    "Address" : "Enderezo",
    "Profile picture" : "Imaxe do perfil",
    "About" : "Sobre",
    "Display name" : "Nome para amosar",
    "Headline" : "Titular",
    "Organisation" : "Organización",
    "Role" : "Cargo",
    "Additional settings" : "Axustes adicionais",
    "Enter the database name for %s" : "Introduza o nome da base de datos para %s",
    "You cannot use dots in the database name %s" : "Non pode usar puntos no nome da base de datos %s",
    "You need to enter details of an existing account." : "Debe introducir os detalles dunha conta existente.",
    "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a  súa responsabilidade!",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux no seu canto.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun contorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
    "Set an admin password." : "Estabeleza un contrasinal de administrador",
    "Cannot create or write into the data directory %s" : "Non é posíbel crear ou escribir no directorio de datos %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Non se atopou a infraestrutura de compartición %s",
    "Sharing backend for %s not found" : "Non se atopou a infraestrutura de compartición para %s",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartiu «%2$s» con Vde. e quere engadir:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s compartiu «%2$s» con Vde. e quere engadir",
    "»%s« added a note to a file shared with you" : "«%s» engadiu unha nota a un ficheiro compartido con Vde.",
    "Open »%s«" : "Abrir «%s»",
    "%1$s via %2$s" : "%1$s mediante %2$s",
    "You are not allowed to share %s" : "Non ten permiso para compartir %s",
    "Cannot increase permissions of %s" : "Non é posíbel incrementar os permisos de %s",
    "Files cannot be shared with delete permissions" : "Non é posíbel compartir ficheiros con permisos de eliminación",
    "Files cannot be shared with create permissions" : "Non é posíbel compartir ficheiros con permisos de creación",
    "Expiration date is in the past" : "Xa pasou a data de caducidade",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Non é posíbel estabelecer a data de caducidade máis alo de %n día no futuro","Non é posíbel estabelecer a data de caducidade máis alo de %n días no futuro"],
    "Sharing is only allowed with group members" : "Só se permite compartir cos membros do grupo",
    "%1$s shared »%2$s« with you" : "%1$s compartiu «%2$s» con Vde.",
    "%1$s shared »%2$s« with you." : "%1$s compartiu «%2$s» con Vde.",
    "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
    "The requested share does not exist anymore" : "A compartición solicitada xa non existe",
    "The requested share comes from a disabled user" : "A compartición solicitada procede dun usuario desactivado",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Non se creou o usuario porque acadouse o límite de usuarios. Consulte as súas notificacións para obter máis información.",
    "Could not find category \"%s\"" : "Non foi posíbel atopar a categoría «%s»",
    "Sunday" : "domingo",
    "Monday" : "luns",
    "Tuesday" : "martes",
    "Wednesday" : "mércores",
    "Thursday" : "xoves",
    "Friday" : "venres",
    "Saturday" : "sábado",
    "Sun." : "dom.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "mér.",
    "Thu." : "xov.",
    "Fri." : "ven.",
    "Sat." : "sáb.",
    "Su" : "do",
    "Mo" : "lu",
    "Tu" : "ma",
    "We" : "mé",
    "Th" : "xo",
    "Fr" : "ve",
    "Sa" : "sá",
    "January" : "xaneiro",
    "February" : "febreiro",
    "March" : "marzo",
    "April" : "abril",
    "May" : "maio",
    "June" : "xuño",
    "July" : "xullo",
    "August" : "agosto",
    "September" : "setembro",
    "October" : "outubro",
    "November" : "novembro",
    "December" : "decembro",
    "Jan." : "xan.",
    "Feb." : "feb.",
    "Mar." : "mar.",
    "Apr." : "abr.",
    "May." : "mai.",
    "Jun." : "xuñ.",
    "Jul." : "xul.",
    "Aug." : "ago.",
    "Sep." : "set.",
    "Oct." : "out.",
    "Nov." : "nov.",
    "Dec." : "dec.",
    "A valid password must be provided" : "Debe fornecer un contrasinal",
    "Login canceled by app" : "Acceso cancelado pola aplicación",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non é posíbel instalar a aplicación «%1$s» por mor de non cumprirse as dependencias: %2$s",
    "a safe home for all your data" : "un acubillo seguro para todos os seus datos",
    "File is currently busy, please try again later" : "O ficheiro está ocupado neste momento, ténteo máis adiante.",
    "Cannot download file" : "Non é posíbel descargar o ficheiro",
    "Application is not enabled" : "A aplicación non está activada",
    "Authentication error" : "Produciuse un erro de autenticación",
    "Token expired. Please reload page." : "Testemuño caducado. Recargue a páxina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Non hai controladores de base de datos (sqlite, mysql, ou postgresql) instalados.",
    "Cannot write into \"config\" directory." : "Non é posíbel escribir no directorio «config».",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de configuración. Véxa %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se prefire conservar o ficheiro «config.php» como de só lectura, marque a opción «config_is_read_only» como «true» nel. Vexa %s",
    "Cannot write into \"apps\" directory." : "Non é posíbel escribir no directorio «apps».",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio de aplicacións ou desactivando a tenda de aplicacións no ficheiro de configuración.",
    "Cannot create \"data\" directory." : "Non é posíbel crear o directorio «data».",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Isto, normalmente, pódese solucionar dándolle ao servidor web acceso de escritura ao directorio raíz. Véxa %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Os permisos normalmente pódense corrixir dándolle ao servidor web acceso de escritura ao directorio raíz. Véxa %s.",
    "Your data directory is not writable." : "Non se pode escribir no seu directorio de datos.",
    "Setting locale to %s failed." : "Produciuse un fallo ao axustar a configuración rexional en %s.",
    "Please install one of these locales on your system and restart your web server." : "Instale un destes locais no seu sistema e reinicie o seu servidor web.",
    "PHP module %s not installed." : "O módulo PHP %s non está instalado.",
    "Please ask your server administrator to install the module." : "Pídalle á administración do seu servidor que instale o módulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "O axuste de PHP «%s» non está estabelecido a «%s».",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Cambiar este axuste no ficheiro php.ini fará que Nextcloud funcione de novo",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está estabelecido en <code>%s</code> no canto do valor agardado <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para solucionar este problema, estabeleza <code>mbstring.func_overload</code> en <code>0</code> no seu php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Semella que PHP foi configurado para quitar bloques de documentos en liña. Isto fará que varios aplicativos sexan inaccesíbeis. ",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isto probabelmente se debe unha caché/acelerador como Zend OPcache ou eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Instaláronse os módulos de PHP, mais aínda aparecen listados como perdidos?",
    "Please ask your server administrator to restart the web server." : "Pídalle á administración do seu servidor que reinicie o servidor web.",
    "The required %s config variable is not configured in the config.php file." : "Precísase da variábel de configuración %s e non está configurada no ficheiro config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Pídalle á administración do seu servidor que verifique a configuración de Nextcloud.",
    "Your data directory must be an absolute path." : "O seu directorio de datos debe ser unha ruta absoluta.",
    "Check the value of \"datadirectory\" in your configuration." : "Comprobe o valor de «datadirectory» na súa configuración-",
    "Your data directory is invalid." : "O seu directorio de datos non é válido.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrese de que existe un ficheiro chamado «.ocdata» na raíz do directorio de datos.",
    "Action \"%s\" not supported or implemented." : "A acción «%s» non está admitida ou implementada.",
    "Authentication failed, wrong token or provider ID given" : "Produciuse un fallo de autenticación. Deuse un testemuño ou un ID de provedor erróneos.",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Faltan parámetros para completar a solicitude. Parámetros que faltan: «%s»",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "O ID «%1$s» xa está a ser usado polo provedor da nube federada «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "O  provedor de nube federada co ID «%s» non existe.",
    "Could not obtain lock type %d on \"%s\"." : "Non foi posíbel obter un bloqueo do tipo %d en «%s».",
    "Storage unauthorized. %s" : "Almacenamento non autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración incompleta do almacenamento. %s",
    "Storage connection error. %s" : "Produciuse un erro na conexión ao almacenamento. %s",
    "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
    "Storage connection timeout. %s" : "Esgotouse o tempo de conexión co almacenamento. %s",
    "Free prompt" : "Indicación libre",
    "Runs an arbitrary prompt through the language model." : "Procesa unha indicación arbitraria a través do modelo de linguaxe.",
    "Generate headline" : "Xerar título",
    "Generates a possible headline for a text." : "Xera un posíbel título para un texto.",
    "Summarize" : "Resumir",
    "Summarizes text by reducing its length without losing key information." : "Resume o texto reducindo a súa lonxitude sen perder a información clave.",
    "Extract topics" : "Extraer temas",
    "Extracts topics from a text and outputs them separated by commas." : "Extrae temas dun texto e amósaos separados por comas.",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os ficheiros da aplicación %1$s non foron substituídos correctamente. Asegúrese que é unha versión compatíbel co servidor.",
    "404" : "404",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuario que accede debe ser un administrador, un subadministrador ou ter un dereito especial para acceder a esta configuración",
    "Logged in user must be an admin or sub admin" : "O usuario autenticado debe ser un administrador ou subadministrador",
    "Logged in user must be an admin" : "O usuario conectado debe ser un administrador",
    "Full name" : "Nome completo",
    "Unknown user" : "Usuario descoñecido",
    "Enter the database username and name for %s" : "Introduza o nome de usuario da ase de datos e o nome para %s",
    "Enter the database username for %s" : "Introduza o nome de usuario da base de datos para %s",
    "MySQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de MySQL incorrecto",
    "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
    "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
    "Set an admin username." : "Estabeleza un nome de usuario administrador",
    "Sharing %s failed, because this item is already shared with user %s" : "Fallou a compartición de %s por mor de que este elemento xa foi compartido co usuario %s",
    "The username is already being used" : "Este nome de usuario xa está a ser usado",
    "Could not create user" : "Non foi posíbel crear o usuario",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun nome de usuario: «a-z», «A-Z», «0-9», espazos e «_.@-'»",
    "A valid username must be provided" : "Debe fornecer un nome de usuario correcto",
    "Username contains whitespace at the beginning or at the end" : "O nome de usuario contén un espazo en branco no inicio ou no final",
    "Username must not consist of dots only" : "O nome de usuario non debe consistir só de puntos",
    "Username is invalid because files already exist for this user" : "O nome de usuario non é válido porque xa existen ficheiros para este usuario",
    "User disabled" : "Usuario desactivado",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Precísase, cando menos, de libxml2 2.7.0. Actualmente esta instalado %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Para arranxar esta incidencia, actualice a versión de libxml2 e reinicie o servidor web. ",
    "PostgreSQL >= 9 required." : "Precísase de PostgreSQL >= 9.",
    "Please upgrade your database version." : "Anove a versión da súa base de datos",
    "Your data directory is readable by other users." : "Outros usuarios poden leer o seu directorio de datos.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outros usuarios."
},
"nplurals=2; plural=(n != 1);");
